/***************************************************************************
 *   Copyright (C) 2004 by Alessandro Bonometti                            *
 *   bauno@bauniga.baita                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <kapplication.h>
#include <kconfig.h>
#include "globals.h"
#include <qdir.h>
#include <kmessagebox.h>
#include <klocale.h>
 
 
Configuration & Config( )
{
	static Configuration conf;
	return conf;
}

Configuration::Configuration( )
{
	read();
	
}

void Configuration::read( )
{
	KConfig *conf=kapp->config();
	
	conf->setGroup("General");
	configured=conf->readBoolEntry("configured", false);
	dbDir=conf->readPathEntry("dbdir", QDir::homeDirPath() + "/klibido/db");
	decodeDir=conf->readPathEntry("decodedir", QDir::homeDirPath() + "/klibido/decoded");
	tmpDir=conf->readPathEntry("tmpDir", QDir::homeDirPath() + "/klibido/tmp");
	
	conf->setGroup("Decode");
	overwriteExisting=conf->readBoolEntry("overwriteExisting", false);
	deleteFailed=conf->readBoolEntry("deleteFailed", false);
	
	conf->setGroup("HeaderList");
	showFrom = conf->readBoolEntry("showfrom", false);
	showDetails = conf->readBoolEntry("showdetails", true);
	showDate = conf->readBoolEntry("showdate", true);
	allowExpansion = conf->readBoolEntry("allowexpansion", true);
	
	alwaysDoubleClick = conf->readBoolEntry("alwaysdoubleclick", false);
	
	keepListSettings = conf->readBoolEntry("keeplistsettings", false);
	
}

void Configuration::write( ) const
{
	KConfig *conf=kapp->config();
	conf->setGroup("General");
	conf->writeEntry("configured", configured);
	conf->writePathEntry("dbdir", dbDir);
	conf->writePathEntry("decodedir", decodeDir);
	conf->writePathEntry("tmpDir", tmpDir);
	
	conf->setGroup("Decode");
	conf->writeEntry("overwriteExisting", overwriteExisting);
	conf->writeEntry("deleteFailed", deleteFailed);
	
	conf->setGroup("HeaderList");
	conf->writeEntry("showfrom", showFrom);
	conf->writeEntry("showdetails", showDetails);
	conf->writeEntry("showdate", showDate);
	conf->writeEntry("allowexpansion", allowExpansion);
	
	conf->writeEntry("alwaysdoubleclick", alwaysDoubleClick);
	conf->writeEntry("keeplistsettings", keepListSettings);
	
}

bool mkDeepDir( QString dirName )
{
	QDir d;
	
	QString newDir=dirName.mid(0, dirName.findRev('/'));
// 	qDebug("Dir: %s", newDir.latin1());
	if (d.exists(newDir)) 
		return true;
	if (mkDeepDir(newDir)) {
// 		qDebug("create dir: %s", (const char *) newDir);
		if (d.mkdir(newDir))
			return true;
		else return false;
	} else return false;
	
}

bool checkAndCreateDir( QString dirName )
{
	QString dir=QDir::cleanDirPath(dirName);
	dir+='/';
	if (QDir::isRelativePath(dir) ) {
		KMessageBox::error(0, i18n("Please enter only absolute paths"), i18n("Error"));
		return false;
	}
	if (!mkDeepDir(dir))
		return false;
	else { 
		//check if the dir is writable
		QFileInfo fi(dir);
		if (fi.isWritable())
			return true;
		else return false;
		
		
		
	}
}

